
---------------------------------------------------------------------
--== reloader ===--
---------------------------------------------------------------------

local status  = 0
control_raideffects = Turbine.UI.Control()
 
function control_raideffects:Update()
	if status == 1 then
        Turbine.PluginManager.UnloadScriptState( "GibberishReloader" )
    elseif status > 1 then
        self:SetWantsUpdates( false )
        
        control_raideffects = nil
	end

    status = status + 1
end

control_raideffects:SetWantsUpdates( true )


---------------------------------------------------------------------
--== saveFile localization ===--
-- by Ezuri Broda (Gwaihir) --
---------------------------------------------------------------------

locale = "en";
fileSuffix = "";
if Turbine.Shell.IsCommand("hilfe") then
	locale = "de";
	fileSuffix = "__de";
elseif Turbine.Shell.IsCommand("aide") then
	locale = "fr";
	fileSuffix = "__fr";
end

function convertToEuro(dataRaw)
	local newData = {};
	for i, myData in pairs(dataRaw) do
		local tempIndex = nil;
		local tempData = nil;
		if (type(i) == "number") then
			tempIndex = tostring(i);
		else
			tempIndex = i;
		end
		if (type(myData) == "table") then
			tempData = convertToEuro(myData);
		elseif (type(myData) == "number") then
			tempData = tostring(myData);
		else
			tempData = myData;
		end
		newData[tempIndex] = tempData;
	end
	return newData;
end

function convertFromEuro(dataRaw)
	local newData = {}
	for i, myData in pairs(dataRaw) do
		local tempIndex = tonumber(i);
		if (tempIndex == nil) then
			tempIndex = i;
		end
		local tempData = nil;

		if (type(myData) == "table") then
			tempData = convertFromEuro(myData);
		else
			tempData = tonumber(myData);
			if (tempData == nil) then
				tempData = myData;
			end
		end
		newData[tempIndex] = tempData;
	end
	return newData;
	
end


---------------------------------------------------------------------
--== saving ===--
---------------------------------------------------------------------

function SaveSettings()
	if locale == "en" then 
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_char_file", windowdata)
		Turbine.PluginData.Save(Turbine.DataScope.Account, "gibberish_account_file", windowdata)
	else
		local NewSaveFile1 = convertToEuro(windowdata);
		local NewSaveFile2 = convertToEuro(windowdata);
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_char_file" .. fileSuffix, NewSaveFile1)
		Turbine.PluginData.Save(Turbine.DataScope.Account, "gibberish_account_file" .. fileSuffix, NewSaveFile2)	
	end

end

function SaveLibrary()

	if locale == "en" then 
		Turbine.PluginData.Save(Turbine.DataScope.Account, "gibberish_library", library)
	else
		local NewSaveFile1 = convertToEuro(library);
		Turbine.PluginData.Save(Turbine.DataScope.Account, "gibberish_library" .. fileSuffix, NewSaveFile1)	
	end

end

Turbine.Plugin.Unload = function()

	UnloadSave("Gibberish unload.")

end

---------------------------------------------------------------------
--== misc ===--
---------------------------------------------------------------------

function UnloadSave(message)
	local list = {}

	for i,windata in ipairs(windowdata) do 

		if (windata["load"]) then
			if windows[i]~= nil then
				list[i] =  windows[i]:GetRunningTriggerList()
			end
		end

	end

	if locale == "en" then
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_running_triggerlist", list)
	else 
		local NewSavelist = convertToEuro(list)
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_running_triggerlist" .. fileSuffix, NewSavelist)
	end


	OptionsReload()

	--settings_Close()
	-- if moving then
	-- 	window_MovingChanged()
	-- end

	if message ~= nil then
		Turbine.Shell.WriteLine(message)
	end
	
	SortWindows()
end

function ReloadPlugin(message)


        Turbine.PluginManager.LoadPlugin( "GibberishReloader" )

end

function OptionsReload()

	local temp = {}
	if settings_window == nil then
		temp["options_open"] = false
	else
		temp["options_open"] = true

		if settings_window.selected_window_index ~= nil then
			temp["options_windowselection"] = settings_window.selected_window_index
		else
			temp["options_windowselection"] = false
		end

		if settings_window.trigger_window ~= nil then
			local temp_data = settings_window.trigger_window.data

		else
			temp["options_trigger"] = false
		end
	end

	
	temp["move_windows"] = moving
	temp["show_groups"] = show_groups
	temp["show_grid"] = show_grid

	if collectors_window == nil then
		temp["collection_open"] = false
	else
		temp["collection_open"] = true
	end


	if locale == "en" then
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_optionwindow_state", temp)
	else 
		local NewSavelist = convertToEuro(temp)
		Turbine.PluginData.Save(Turbine.DataScope.Character, "gibberish_optionwindow_state" .. fileSuffix, NewSavelist)
	end

end

---------------------------------------------------------------------
--== load in ===--
---------------------------------------------------------------------

function LoadTriggerFromReloadFile(list)

	--local list = start_running_triggerlist

    if locale ~= "en" then
        list = convertFromEuro(list);
    end

    local gt = Turbine.Engine.GetGameTime()

    for i,windata in ipairs(windowdata) do 

        if list[i] ~= nil then
			
            for j, trig in ipairs(list[i]) do
                if (trig["start_time"] + trig["duration"]) > gt and trig["data"] ~= nil then
                    windows[i]:CheckForAdd(windows[i], trig["key"], trig["start_time"], trig["duration"], trig["data"]["icon"], trig["text"], trig["data"], true)
                end
            end
        end
    end
end



if Turbine.PluginData.Load(Turbine.DataScope.Account, "gibberish_account_file" .. fileSuffix) ~= nil then

	windowdata = Turbine.PluginData.Load(Turbine.DataScope.Account, "gibberish_account_file" .. fileSuffix)
	if locale ~= "en" then
		windowdata = convertFromEuro(windowdata);
	end

    if Turbine.PluginData.Load(Turbine.DataScope.Character, "gibberish_char_file" .. fileSuffix) ~= nil then

        local chardata = Turbine.PluginData.Load(Turbine.DataScope.Character, "gibberish_char_file" .. fileSuffix)
		if locale ~= "en" then
			chardata = convertFromEuro(chardata);
		end
	
        windowdata["logo"] = chardata["logo"]
        windowdata["settings"] = chardata["settings"]
        windowdata["track_effects_group"] = chardata["track_effects_group"]
        windowdata["track_effects_target"] = chardata["track_effects_target"]

        if chardata["reload_after_groupchanges"] == nil then
            windowdata["reload_after_groupchanges"] = true
        else
            windowdata["reload_after_groupchanges"] = chardata["reload_after_groupchanges"]
        end

        if windowdata["window_groups"] == nil then
            windowdata["window_groups"] = {}
            chardata["window_groups"] = {}
        end

        if chardata["window_groups"] == nil then
            chardata["window_groups"] = {}
        end


        if windowdata["next_group_id"] == nil then
            windowdata["next_group_id"] = 1
        end

        for key, value in ipairs(chardata["window_groups"]) do
            if value["id"] == nil then
                value["id"] = key
            end
        end

        for key, value in ipairs(windowdata["window_groups"]) do
            if value["id"] == nil then
                value["id"] = windowdata["next_group_id"]
                windowdata["next_group_id"] = windowdata["next_group_id"] + 1
            end

			local bool = false
            for k, v in ipairs(chardata["window_groups"]) do

                if value["id"] == v["id"] then
                    value["load"] = v["load"] 
					value["collapsed"] =  v["collapsed"] 
					bool = true
                end
			end
			if bool == false then
				value["load"] = false
			end
        end

        for i,w_data in ipairs(windowdata) do

			for key, value in ipairs(LIST_NAMES) do
                if w_data[value] == nil then
                    w_data[value] = {}
                else
                    for k,v in ipairs(w_data[value]) do
                        if v["id"] == nil then
                            v["id"] = i..k..Turbine.Engine.GetGameTime()
                        end
                    end
                end
            end



            local bool = false

            for j,c_data in ipairs(chardata) do

                if w_data["id"] == c_data["id"] then
                    w_data["load"] = c_data["load"]
                    w_data["width"] =  c_data["width"]
                    w_data["height"] =  c_data["height"]
                    w_data["left"] = c_data["left"]
                    w_data["top"] =  c_data["top"]

                    bool = true
                end

            end

            if bool == false then
                w_data["load"] = false
            end

        end

    else

        for i,w_data in ipairs(windowdata) do

            w_data["load"] = false
            w_data["left"] = 100
            w_data["top"] = 200

        end
        
    end

else

    windowdata["next_id"] = 1
    windowdata["track_effects_group"] = true
    windowdata["track_effects_target"] = false
    windowdata["reload_after_groupchanges"] = true

    windowdata["next_group_id"] = 1
    windowdata["window_groups"] = {}

    windowdata["logo"] = {}
    windowdata["logo"]["left"] = 300
    windowdata["logo"]["top"] = 400
    windowdata["logo"]["locked"] = false

    windowdata["settings"] = {}
    windowdata["settings"]["left"] = 400
    windowdata["settings"]["top"] = 200
    windowdata["settings"]["width"] = 550
	windowdata["settings"]["height"] = 400
    windowdata["settings"]["show_tooltips"] = true

    windowdata["collection"] = {}
    windowdata["collection"]["left"] = 400
    windowdata["collection"]["top"] = 200
    windowdata["collection"]["width"] = 200
    windowdata["collection"]["height"] = 330


end



function LoadOptionsFromReloadFile(list)

	if list["show_groups"] == false then
		show_groups = false
	else
		show_groups = true
	end
	if list["show_grid"] == false then
		show_grid = false
	else
		show_grid = true
	end

	if list["move_windows"] == true then
		window_MovingChanged()
	end

	if list["options_open"] == true then
		settings_Open()
		if list["options_windowselection"] ~= false then
			if windowdata[list["options_windowselection"]] ~= nil then
				settings_window:WindowSelectionChanged(list["options_windowselection"])
			end
		end
	end

	if list["collection_open"] == true then
		collection_Open()
	end

end



import "Souru.Gibberish.Trigger"


Trigger.window_CreateAll()
Trigger.checkAllSkills()
Trigger.AddSelfEffectEvents()
if windowdata["track_effects_target"] then
    Trigger.AddEventTargetEffects()
end
if windowdata["track_effects_group"] then
    Trigger.AddGroupEffectEvents()
end

if Turbine.PluginData.Load(Turbine.DataScope.Account, "gibberish_library" .. fileSuffix) ~= nil then
	library = Turbine.PluginData.Load(Turbine.DataScope.Account, "gibberish_library" .. fileSuffix)
	if locale ~= "en" then
        library = convertFromEuro(library);
    end
end

--start_running_triggerlist = nil

if Turbine.PluginData.Load(Turbine.DataScope.Character, "gibberish_running_triggerlist" .. fileSuffix) ~= nil then
	--start_running_triggerlist = 
    LoadTriggerFromReloadFile(Turbine.PluginData.Load(Turbine.DataScope.Character,  "gibberish_running_triggerlist" .. fileSuffix))
end

-- delay = Turbine.UI.Control()
-- delayTimer = Turbine.Engine.GetGameTime()+1
-- delay.Update = function()

-- 	if delayTimer <= Turbine.Engine.GetGameTime() then
-- 		delay:SetWantsUpdates(false)
-- 		LoadTriggerFromReloadFile()
-- 	end

-- end
-- delay:SetWantsUpdates(true)

if Turbine.PluginData.Load(Turbine.DataScope.Character, "gibberish_optionwindow_state" .. fileSuffix) ~= nil then
    LoadOptionsFromReloadFile(Turbine.PluginData.Load(Turbine.DataScope.Character,  "gibberish_optionwindow_state" .. fileSuffix))
end

c_icon = UI.Settings.ControlIcon(windowdata["logo"])