
function TrimArticles(name)
	name = string.gsub(name, "^[Dd]ie ", "");
	name = string.gsub(name, "^[Dd]em ", "");
	name = string.gsub(name, "^[Dd]er ", "");
	name = string.gsub(name, "^[Dd]en ", "");
	return name;
end

function trim_articles(name)
	if (name == nil) then
		return nil;
	end

	-- Articles possibles: Mayara, LeMayara, Le Mayara, LaMayara, La Mayara, L' Mayara, L’Mayara, et peut être d'autres?
	return string.gsub(name, "^[Ll].-(%u)", "%1");
end

--CA parse-function

ParseCombatChat = {}

ParseCombatChat["en"] = function(line)

	-- 1) Damage line ---
	
	local initiatorName,avoidAndCrit,skillName,targetNameAmountAndType = string.match(line,"^(.*) scored a (.*)hit(.*) on (.*)%.$"); -- (updated in v4.1.0)
	
	if (initiatorName ~= nil) then
		
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		
		local avoidType =
			string.match(avoidAndCrit,"^partially blocked") and 8 or
			string.match(avoidAndCrit,"^partially parried") and 9 or
			string.match(avoidAndCrit,"^partially evaded") and 10 or 1;
		local critType =
			string.match(avoidAndCrit,"critical $") and 2 or
			string.match(avoidAndCrit,"devastating $") and 3 or 1;
		skillName = string.match(skillName,"^ with (.*)$") or L.DirectDamage; -- (as of v4.1.0)
		
		local targetName,amount,dmgType,moralePower = string.match(targetNameAmountAndType,"^(.*) for ([%d,]*) (.*)damage to (.*)$");
		-- damage was absorbed
		if targetName == nil then
			targetName = string.gsub(targetNameAmountAndType,"^[Tt]he ","");
			amount = 0;
			dmgType = 13;
			moralePower = 3;
		-- some damage was dealt
		else
			targetName = string.gsub(targetName,"^[Tt]he ","");
			amount = string.gsub(amount,",","")+0;
      
      dmgType = string.match(dmgType, "^%(.*%) (.*)$") or dmgType; -- 4.2.3 adjust for mounted combat
			-- note there may be no damage type
			dmgType = 
				dmgType == "Common " and 1 or
				dmgType == "Fire " and 2 or
				dmgType == "Lightning " and 3 or
				dmgType == "Frost " and 4 or
				dmgType == "Acid " and 5 or
				dmgType == "Shadow " and 6 or
				dmgType == "Light " and 7 or
				dmgType == "Beleriand " and 8 or
				dmgType == "Westernesse " and 9 or
				dmgType == "Ancient Dwarf-make " and 10 or 
        dmgType == "Orc-craft " and 11 or
        dmgType == "Fell-wrought " and 12 or 13;
			moralePower = (moralePower == "Morale" and 1 or moralePower == "Power" and 2 or 3);
		end
		
		-- Currently ignores damage to power
		if (moralePower == 2) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,amount,avoidType,critType,dmgType;
	end
	
	-- 2) Heal line --
	--     (note the distinction with which self heals are now handled)
	--     (note we consider the case of heals of zero magnitude, even though they presumably never occur)
	local initiatorName,crit,skillNameTargetNameAmountAndType = string.match(line,"^(.*) applied a (.-)heal (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		local critType =
			crit == "critical " and 2 or
			crit == "devastating " and 3 or 1;
		
		local skillNameTargetNameAndAmount,ending = string.match(skillNameTargetNameAmountAndType,"^(.*)to (.*)$");
		local targetName,skillName,amount;
		moralePower = (ending == "Morale" and 1 or (ending == "Power" and 2 or 3));
		-- heal was absorbed (unfortunately it appears this actually shows as a "hit" instead, so we never get into the first conditional)
		if (moralePower == 3) then
			targetName = string.gsub(ending,"^[Tt]he ","");
			amount = 0;
			-- skill name will equal nil if this was a self heal
			skillName = string.match(skillNameTargetNameAndAmount,"^with (.*) $");
		-- heal applied
		else
			skillName,targetName,amount = string.match(skillNameTargetNameAndAmount,"^(.*)to (.*) restoring ([%d,]*) points? $");
			targetName = string.gsub(targetName,"^[Tt]he ","");
			amount = string.gsub(amount,",","")+0;
			-- skill name will equal nil if this was a self heal
			skillName = string.match(skillName,"^with (.*) $");
		end
		
		-- rearrange if this was a self heal
		if (skillName == nil) then
			skillName = initiatorName;
			initiatorName = targetName;
		end
		
		-- Update
		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end
	
	-- 3) Buff line --
	
	local initiatorName,skillName,targetName = string.match(line,"^(.*) applied a benefit with (.*) on (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- Update
		return 17,initiatorName,targetName,skillName;
	end
	
	-- 4) Avoid line --
	local initiatorNameMiss,skillName,targetNameAvoidType = string.match(line,"^(.*) to use (.*) on (.*)%.$");
	
	if (initiatorNameMiss ~= nil) then
		initiatorName = string.match(initiatorNameMiss,"^(.*) tried$");
		local targetName, avoidType;
		-- standard avoid
		if (initiatorName ~= nil) then
			initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
			targetName,avoidType = string.match(targetNameAvoidType,"^(.*) but (.*) the attempt$");
			targetName = string.gsub(targetName,"^[Tt]he ","");
			avoidType = 
				string.match(avoidType," blocked$") and 5 or
				string.match(avoidType," parried$") and 6 or
				string.match(avoidType," evaded$") and 7 or
				string.match(avoidType," resisted$") and 4 or
				string.match(avoidType," was immune to$") and 3 or 1;
				
		-- miss or deflect (deflect added in v4.2.2)
		else
			initiatorName = string.match(initiatorNameMiss,"^(.*) missed trying$");
      if (initiatorName == nil) then
        initiatorName = string.match(initiatorNameMiss,"^(.*) was deflected trying$");
        avoidType = 11;
      else
        avoidType = 2;
      end
      
			initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
			targetName = string.gsub(targetNameAvoidType,"^[Tt]he ","");
		end
		
		-- Sanity check: must have avoided in some manner
		if (avoidType == 1) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,0,avoidType,1,13;
	end
	
	-- 5) Reflect line --
	
	local initiatorName,amount,dmgType,targetName = string.match(line,"^(.*) reflected ([%d,]*) (.*) to the Morale of (.*)%.$");
	
	if (initiatorName ~= nil) then
		local skillName = "Reflect";
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		targetName = string.gsub(targetName,"^[Tt]he ","");
		amount = string.gsub(amount,",","")+0;
		
		local dmgType = string.match(dmgType,"^(.*)damage$");
		-- a damage reflect
		if (dmgType ~= nil) then
			dmgType = 
				dmgType == "Common " and 1 or
				dmgType == "Fire " and 2 or
				dmgType == "Lightning " and 3 or
				dmgType == "Frost " and 4 or
				dmgType == "Acid " and 5 or
				dmgType == "Shadow " and 6 or
				dmgType == "Light " and 7 or
				dmgType == "Beleriand " and 8 or
				dmgType == "Westernesse " and 9 or
				dmgType == "Ancient Dwarf-make " and 10 or
				dmgType == "Orc-craft " and 11 or
				dmgType == "Fell-wrought " and 12 or 13;
						
			-- Update
			return 1,initiatorName,targetName,skillName,amount,1,1,dmgType;
		-- a heal reflect
		else
			-- Update
			return 3,initiatorName,targetName,skillName,amount,1;
		end
	end
	
	-- 6) Temporary Morale bubble line (as of 4.1.0)
  local amount = string.match(line,"^You have lost ([%d,]*) points of temporary Morale!$");
	if (amount ~= nil) then
		amount = string.gsub(amount,",","")+0;
		
		-- the only information we can extract directly is the target and amount
		return 14,nil,player.name,nil,amount;
	end
	
	-- 7) Combat State Break notice (as of 4.1.0)
	
	-- 7a) Root broken
	local targetName = string.match(line,"^.* ha[sv]e? released (.*) from being immobilized!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7b) Daze broken
	local targetName = string.match(line,"^.* ha[sv]e? freed (.*) from a daze!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7c) Fear broken (TODO: Check)
	local targetName = string.match(line,"^.* ha[sv]e? freed (.*) from a fear!$");
	if (targetName ~= nil) then
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 8) Interrupt line --
	
	local targetName, initiatorName = string.match(line,"^(.*) was interrupted by (.*)!$");
	
	if (targetName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- Update
		return 7,initiatorName,targetName;
	end
	
	-- 9) Dispell line (corruption removal) --
	
	local corruption, targetName = string.match(line,"You have dispelled (.*) from (.*)%.$");
	
	if (corruption ~= nil) then
		initiatorName = player.name;
		targetName = string.gsub(targetName,"^[Tt]he ","");
		
		-- NB: Currently ignore corruption name
		
		-- Update
		return 8,initiatorName,targetName;
	end
	
	-- 10) Defeat lines ---
	
	-- 10a) Defeat line 1 (mob or played was killed)
	local initiatorName = string.match(line,"^.* defeated (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10b) Defeat line 2 (mob died)
	local initiatorName = string.match(line,"^(.*) died%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10c) Defeat line 3 (a player was killed or died)
	local initiatorName = string.match(line,"^(.*) has been defeated%.$");

	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10d) Defeat line 4 (you were killed)
	local match = string.match(line,"^.* incapacitated you%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10e) Defeat line 5 (you died)
	local match = string.match(line,"^You have been incapacitated by misadventure%.$");

	if (match ~= nil) then
		initiatorName = player.name;
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 10f) Defeat line 6 (you killed a mob)
	local initiatorName = string.match(line,"^Your mighty blow topples (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
		
		-- Update
		return 9,initiatorName;
	end
	
	-- 11) Revive lines --
	
	-- 11a) Revive line 1 (player revived)
	local initiatorName = string.match(line,"^(.*) has been revived%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11b) Revive line 2 (player succumbed)
	local initiatorName = string.match(line,"^(.*) has succumbed to .* wounds%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = string.gsub(initiatorName,"^[Tt]he ","");
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11c) Revive line 3 (you were revived)
	local match = string.match(line,"^You have been revived%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11d) Revive line 4 (you succumbed)
	local match = string.match(line,"^You succumb to your wounds%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- if we reach here, we were unable to parse the line
	--  (note there is very little that isn't parsed)
end


ParseCombatChat["de"] = function(line)

	-- 1) Damage line ---
	
	local initiatorName,avoidAndCrit,skillName,targetNameAmountAndType = string.match(line,"^(.*) gelang ein (.*)Treffer mit \"(.*)\" gegen (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		
		local avoidType =
			string.match(avoidAndCrit,"^teilweise geblockter") and 8 or
			string.match(avoidAndCrit,"^teilweise parierter") and 9 or
			string.match(avoidAndCrit,"^teilweise ausgewichener") and 10 or 1;
		local critType =
			string.match(avoidAndCrit,"kritischer $") and 2 or
			string.match(avoidAndCrit,"zerst\195\182rerischer $") and 3 or 1;
		
		local targetName,amount,dmgType,moralePower = string.match(targetNameAmountAndType, "^(.*) f\195\188r ([%d,]*) Punkte Schaden des Typs \"(.*)\" auf (.*)$");
		-- damage was absorbed
		if targetName == nil then
			targetName = TrimArticles(targetNameAmountAndType);
			amount = 0;
			dmgType = 13;
			moralePower = 3;
		-- some damage was dealt
		else
			targetName = TrimArticles(targetName);
			amount = string.gsub(amount,",","")+0;
			-- note there may be no damage type
			dmgType = 
				dmgType == "Allgemein" and 1 or
				dmgType == "Feuer" and 2 or
				dmgType == "Blitz" and 3 or
				dmgType == "Frost" and 4 or
				dmgType == "S\195\164ure" and 5 or
				dmgType == "Schatten" and 6 or
				dmgType == "Licht" and 7 or
				dmgType == "Beleriand" and 8 or
				dmgType == "Westernis" and 9 or
				dmgType == "Uralte Zwergenart" and 10 or
				dmgType == "Ork-Waffe" and 11 or
				dmgType == "Hass" and 12 or 13;
			moralePower = (moralePower == "Moral" and 1 or moralePower == "Kraft" and 2 or 3);
		end
		
		-- Currently ignores damage to power
		if (moralePower == 2) then return nil end
		
		-- Update
		return 1,initiatorName,targetName,skillName,amount,avoidType,critType,dmgType;
	end
	
	-- 2) Heal line --
	
	--     (note the distinction with which self heals are now handled)
	--     (note we consider the case of heals of zero magnitude, even though they presumably never occur)
	local initiatorName,crit,skillNameTargetNameAmountAndType = string.match(line,"^(.*) wandte \"(.*)Heilung\" mit (.*)%.$");

	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		local critType =
			crit == "kritische " and 2 or
			crit == "zerst\195\182rerische " and 3 or 1;
			
		local skillNameTargetNameAndAmount,ending = string.match(skillNameTargetNameAmountAndType,"^(.*) Punkte (.*) wiederherstellte$");
		moralePower = (ending == "Moral" and 1 or ending == "Kraft" and 2 or 3);
		
		skillName,targetName,amount = string.match(skillNameTargetNameAndAmount,"^\"(.*)\" auf (.*) an, was ([%d,]*)$");
		targetName = TrimArticles(targetName);
		amount = string.gsub(amount,",","")+0;
		
		-- Update
		return (moralePower == 2 and 4 or 3),initiatorName,targetName,skillName,amount,critType;
	end
	
	-- 2.2) Self Heal
	
	--		(note that the self heal line is totally differend in comparision to the normal heal line in the german client)
	
	local skillName, initiatorName, critType, amount, moralPower = string.match(line, "^(.*) verursacht bei (.*) \"(.*)Heilung\" und stellt ([%d,]*) Punkte (.*) wieder her%.");
	if(initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		amount = string.gsub(amount, ",", "")+0;
		moralPower = (moralPower == "Moral" and 1 or moralPower == "Kraft" and 2 or 3);
		critType = critType == "kritische " and 2 or
				   critType == "zerst\195\182rerische " and 3 or 1;
		
		return (moralPower == 2 and 4 or 3), initiatorName, initiatorName, skillName, amount, critType;
	end
	
	-- 3) Buff line --
	local initiatorName,skillName,targetName = string.match(line,"^(.*) wandte \"Vorteil\" mit \"(.*)\" auf (.*) an%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		targetName = TrimArticles(targetName);
		-- Update
		return 17,initiatorName,targetName,skillName;
	end
	
	-- 4) Avoid line --


	-- standard avoid
	local initiatorName,targetName,skillName,erSie,avoidType = string.match(line,"^(.*) wollte (.*) mit (.*) treffen\, aber(.*)konterte den Versuch mit (.*).");
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		targetName = TrimArticles(targetName);
		skillName = string.gsub(skillName, "\"", "");
		avoidType = string.gsub(avoidType, "\"", "");
		avoidType = 
				string.match(avoidType,"Blocken") and 5 or
				string.match(avoidType,"Parieren") and 6 or
				string.match(avoidType,"Ausweichen") and 7 or
				string.match(avoidType,"Widerstehen") and 4 or
				string.match(avoidType,"Immunit\195\164t") and 3 or 1;
		-- Sanity check: must have avoided in some manner
		if (avoidType == 1) then return nil end
		return 1,initiatorName,targetName,skillName,0,avoidType,1,10;
	end
		
	-- miss
	local initiatorName, targetName, skillName = string.match(line, "^(.*) verfehlte (.*) mit (.*)%.");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		targetName = TrimArticles(targetName);
		skillName = string.gsub(skillName, "\"", "");
		local avoidType = 2;
		-- Update
		return 1,initiatorName,targetName,skillName,0,avoidType,1,10;
	end
		
	
	-- 5) Reflect line --
	
	local initiatorName, amount, reflectType, targetName = string.match(line, "^(.*) reflektierte ([%d,]*) Punkte (.*) von (.*).$");
	if(initiatorName ~= nil) then
		local skillName = "Reflektiert";
		initiatorName = TrimArticles(initiatorName);
		targetName = TrimArticles(targetName);
		
		amount = string.gsub(amount,",","")+0;
		local dmgType = string.match(reflectType, "^Schaden des Typs (.*) auf Moral$");
		
		if(dmgType ~= nil) then
			dmgType = 
				dmgType == "\"Allgemein\""  and 1 or
				dmgType == "\"Feuer\"" and 2 or
				dmgType == "\"Blitz\"" and 3 or
				dmgType == "\"Frost\"" and 4 or
				dmgType == "\"S\195\164ure\"" and 5 or
				dmgType == "\"Schatten\"" and 6 or
				dmgType == "\"Licht\"" and 7 or
				dmgType == "\"Beleriand\"" and 8 or
				dmgType == "\"Westernis\"" and 9 or
				dmgType == "\"Uralte Zwergenart\"" and 10 or
				dmgType == "\"Ork-Waffe\"" and 11 or
				dmgType == "\"Hass\"" and 12 or 13;
			-- a dmg reflect
			return 1,initiatorName,targetName,skillName,amount,1,1,dmgType;
		else
			-- a heal reflect
			return 3,initiatorName,targetName,skillName,amount,1;
		end
	end
	
	-- 6) Temporary Morale bubble line (as of 4.1.0)
	local amount = string.match(line,"^Ihr habt ([%d,]*) Punkte Moral (tempor\195\164r) verloren!$");
	if (amount ~= nil) then
		amount = string.gsub(amount,",","")+0;
		-- the only information we can extract directly is the target and amount
		return 14,nil,player.name,nil,amount;
	end
	
	-- 7) Combat State Break notice (as of 4.1.0)
	
	-- 7a) Root broken
	local targetName = string.match(line,"^.* hab?t die Bewegungslosigkeit von (.*) beendet!$");
	if (targetName ~= nil) then
		targetName = TrimArticles(targetName);
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7b) Daze broken
	local targetName = string.match(line,"^.* hab?t die Benommenheit von (.*) beendet!$");
	if (targetName ~= nil) then
		targetName = TrimArticles(targetName);
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
	
	-- 7c) Fear broken
	local targetName = string.match(line,"^.* hab?t mit einem Angriff die Furcht von (.*) beseitigt!$");
	if(targetName ~= nil) then
		targetName = TrimArticles(targetName);
		-- the only information we can extract directly is the target name
		return 16,nil,targetName,nil;
	end
		
	
	-- 8) Interrupt line --
	local targetName,initiatorName = string.match(line,"^(.*) wurde durch (.*) unterbochen!");
	if (targetName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		targetName = TrimArticles(targetName);
		
		-- Update
		return 7,initiatorName,targetName;
	end
	
	-- 9) Dispell line (corruption removal) --
	local corruption, targetName = string.match(line,"Von (.*) geheilt: (.*)");
	
	if (corruption ~= nil) then
		-- NB: Currently ignore corruption name
		
		-- Update
		return 8,player.name,targetName;
	end
	
	-- 10) Defeat lines ---
	
	-- 10a) Defeat line 1 (mob or played was killed)
	local initiatorName = string.match(line,"^Durch .* besiegt: (.*)%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		-- Update
		return 9,initiatorName;
	end
	
	-- 10b) Defeat line 2 (mob died)
	local initiatorName = string.match(line,"^(.*) ist gestorben%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		-- Update
		return 9,initiatorName;
	end
	
	-- 10c) Defeat line 3 (a player was killed or died)
	local initiatorName = string.match(line,"^(.*) wurde besiegt%.$");

	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		-- Update
		return 9,initiatorName;
	end
	
	-- 10d) Defeat line 4 (you were killed)
	local match = string.match(line,"^.* hat Euch au\195\159er Gefecht gesetzt%.$");

	if (match ~= nil) then
		-- Update
		return 9,player.name;
	end
	
	-- 10e) Defeat line 5 (you died)
	local match = string.match(line,"^Ihr wurdet durch ein Missgeschick au\195\159er Gefecht gesetzt%.$");

	if (match ~= nil) then
		-- Update
		return 9,player.name;
	end
	
	-- 11) Revive lines --
	
	-- 11a) Revive line 1 (player revived)
	local initiatorName = string.match(line,"^(.*) wurde wiederbelebt%.$");
	
	if (initiatorName ~= nil) then
		initiatorName = TrimArticles(initiatorName);
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11b) Revive line 2 (player succumbed)
	local initiatorName = string.match(line,"^(.*) ist .* Wunden erlegen%.$");
	
	if (initiatorName ~= nil) then
	  initiatorName = TrimArticles(initiatorName);
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11c) Revive line 3 (you were revived)
	local match = string.match(line,"^Ihr wurdet wiederbelebt%.$");
	
	if (match ~= nil) then
		-- Update
	  return 10,player.name;
	end
	
	-- 11d) Revive line 4 (you succumbed)
	local match = string.match(line,"^Ihr erliegt Euren Verletzungen%.$");
	
	if (match ~= nil) then
		-- Update
	  return 10,player.name;
	end
	
	-- if we reach here, we were unable to parse the line
	--  (note there is very little that isn't parsed)
end

ParseCombatChat["fr"] = function(line)

	-- 1) Damage line ---
	
	local initiatorName,avoidAndCrit,skillName,targetName,amount,dmgType,moralePower = string.match(line,"^(.*) a infligé un coup (.*)avec (.*) sur (.*) pour ([%d,]*) points de type (.*) à l'entité ?(.*)%.$"); -- (updated in v4.1.0)
	
	if (initiatorName ~= nil) then
		
		local avoidType =
			string.match(avoidAndCrit,"partiellement bloqué") and 8 or
			string.match(avoidAndCrit,"partiellement paré") and 9 or
			string.match(avoidAndCrit,"partiellement esquivé ") and 10 or 
			1;
		local critType =
			string.match(avoidAndCrit,"critique") and 2 or
			string.match(avoidAndCrit,"dévastateur") and 3 or 1;
			
		-- skillName = string.match(skillName,"^ avec (.*)$") or L.DirectDamage; -- (as of v4.1.0)

    if (printDebug) then
       Turbine.Shell.WriteLine( "damage by "..initiatorName.." skill "..skillName );
    end		
		-- damage was absorbed
		if targetName == nil then
			targetName = string.gsub(targetNameAmountAndType,"^[Tt]he ","");
			amount = 0;
			dmgType = 12;
			moralePower = 3;
		-- some damage was dealt
		else
			amount = string.gsub(amount,",","")+0;
      
---			dmgType = string.match(dmgType, "^%(.*%) (.*)$") or dmgType; -- 4.2.3 adjust for mounted combat
			-- note there may be no damage type
			dmgType = 
				dmgType == "Commun" and 1 or
				dmgType == "Feu" and 2 or
				dmgType == "Foudre" and 3 or
				dmgType == "Froid" and 4 or
				dmgType == "Acide" and 5 or
				dmgType == "Ombre" and 6 or
				dmgType == "Lumière" and 7 or
				dmgType == "Beleriand" and 8 or
				dmgType == "Ouistrenesse" and 9 or
				dmgType == "de nain d'antan" and 10 or 
				dmgType == "Orc" and 11 or
				dmgType == "Fell-wrought" and 12 or 13;
			moralePower = (moralePower == "Morale" and 1 or moralePower == "Puissance" and 2 or 3);
		end
		
		-- Currently ignores damage to power
		if (moralePower == 2) then return nil end
		
		-- Update
		return 1,trim_articles(initiatorName),trim_articles(targetName),skillName,amount,avoidType,critType,dmgType;
	end
	
	-- 2) Heal line --
	--     (note the distinction with which self heals are now handled)
	--     (note we consider the case of heals of zero magnitude, even though they presumably never occur)
	
	--	[slfHeal] Arc du Juste a appliqué un soin critique à Ardichas, redonnant 52 points à l'entité Puissance.
	--  [slfHeal] Esprit de soliloque a appliqué un soin critique à Yogimen, redonnant 228 points à l'entité Moral.
	--  [Heal]    Eleria a appliqué un soin avec Paroles de guérison Ardicapde, redonnant 227 points à Moral.
	initiator_name, match = string.match(line, '^(.*) a appliqu\195\169 un soin (.*)%.$');

	if (initiator_name ~= nil) then
			crit_type =
				string.match(match, 'critique') and 2 or
				string.match(match, 'dévastateur') and 3 or
				1;
			match = string.gsub(match, '^critique ', '');
			match = string.gsub(match, '^dévastateur ', '');

		local self_heal = (string.match(match, '^\195\160 ') and true or false);

		-- Soins personnels (Self heal)
		if (self_heal) then
			skill_name = initiator_name;
			target_name, dmg_amount, morale_power = string.match(match, '^\195\160 (.*), redonnant ([%d,]*) points? \195\160 l\'entit\195\169 ?(.*)$');
			initiator_name = target_name;

		-- Soins sur une cible (Heal applied)
		else
			skill_name, target_name, dmg_amount, morale_power = string.match(match, '^avec (.*) ([^%s]+), redonnant ([%d,]*) points? \195\160 ?(.*)$');
		end

		morale_power = (morale_power == 'Moral' and 1 or (morale_power == 'Puissance' and 2 or 3));
		dmg_amount = (morale_power == 3 and 0 or string.gsub(dmg_amount, ',', '') + 0);

		return (morale_power == 2 and 4 or 3), trim_articles(initiator_name), trim_articles(target_name), skill_name, dmg_amount, crit_type;
	end
	
	-- 3) Buff line --
	-- MarieChantal a appliqué un bénéfice avec Paroles de guérison Eleria.

	local initiatorName,skillName,targetName = string.match(line,"^(.*) a appliqué un bénéfice avec (.*) (.*)%.$");
	
	if (initiatorName ~= nil) then
		
		-- Update
		return 17,trim_articles(initiatorName),trim_articles(targetName),skillName;
	end
	
	-- 4) Avoid line --
	-- L' Profanateur ghâshfra vigoureux a essayé d'utiliser une attaque de lancer faible sur MarieChantal mais a esquivé la tentative.
	-- L' Berserker hante-jours a essayé d'utiliser une double attaque au corps à corps sur Eleria mais elle a paré la tentative.
	-- L' Archer corsaire a essayé d'utiliser une attaque au corps à corps faible sur Cashel mais il a paré la tentative.
	-- Ardichas a essayé d'utiliser Tir pénétrant amélioré : Brûlure sur le Trompeur immonde vigoureux mais il a esquivé la tentative.

	-- 4a) Évitements complets (Full avoids)
	local initiator_name, skill_name, target_name, avoidType = string.match(line, "^(.*) a essayé d'utiliser (.*) sur (.*) mais (.*) la tentative%.$");

	if (initiator_name ~= nil) then
		avoid_Type =
			string.match(avoidType,"bloqué") and 5 or
			string.match(avoidType,"paré") and 6 or
			string.match(avoidType,"esquivé") and 7 or
			string.match(avoidType,"résisté") and 4 or
			string.match(avoidType,"immunisé contre") and 3 or 1;

		if (avoid_type == 1) then
			return nil;
		end
		return 1, trim_articles(initiator_name), trim_articles(target_name), skill_name, 0, avoid_Type, 1, 10;
	end
	
	-- 4b) miss or deflect (deflect added in v4.2.2)
	-- La Berserker hante-jours n'a pas réussi à utiliser une frappe de taille faible sur la Eleria.
	local initiator_name, skill_name, target_name = string.match(line, "^(.*) n'a pas réussi à utiliser (.*) sur (.*)%.$");

	if (initiator_name ~= nil) then
		avoid_type = 2;

		return 1, trim_articles(initiator_name), trim_articles(target_name), skill_name, 0, avoid_type, 1, 10;
	end
	
	-- 5) Reflect line --
	-- Norchador a renvoyé 210 Ombre de dégâts au Moral de la Eleria.
	-- Le Sangsue gardienne a renvoyé 339 points redonnés au Moral de Eleria.
	local initiatorName,amount,dmgType,targetName = string.match(line,"^(.*) a renvoyé ([%d,]*) (.*) au Moral de (.*)%.$");
	
	if (initiatorName ~= nil) then
		local skillName = "Reflect";
		amount = string.gsub(amount,",","")+0;
		
		local dmgType = string.match(dmgType,"^(.*)de dégâts$");
		-- a damage reflect
		if (dmgType ~= nil) then
			dmgType = 
				dmgType == "Commun" and 1 or
				dmgType == "Feu" and 2 or
				dmgType == "Foudre" and 3 or
				dmgType == "Froid" and 4 or
				dmgType == "Acide" and 5 or
				dmgType == "Ombre" and 6 or
				dmgType == "Lumière" and 7 or
				dmgType == "Beleriand" and 8 or
				dmgType == "Ouistrenesse" and 9 or
				dmgType == "Nain d'antan" and 10 or 11;
						
			-- Update
			return 1,trim_articles(initiatorName),trim_articles(targetName),skillName,amount,1,1,dmgType;
		-- a heal reflect
		else
			-- Update
			return 3,trim_articles(initiatorName),trim_articles(targetName),skillName,amount,1;
		end
	end
	
	-- 6) Temporary Morale bubble line (as of 4.1.0)
  local amount = string.match(line,"^Vous avez perdu ([%d,]*) points de Moral temporaire !$");
	if (amount ~= nil) then
		amount = string.gsub(amount,",","")+0;
		
		-- the only information we can extract directly is the target and amount
		return 14,nil,trim_articles(player.name),nil,amount;
	end
	
	-- 7) Combat State Break notice (as of 4.1.0)
	
	-- 7a) Root broken
	initiator_name, target_name = string.match(line, "^(.*) délivrée? ?(.*) de l'immobilisation\194\160!$");

	if (initiator_name ~= nil) then
		initiator_name =
			string.match(initiator_name, "^Vous avez") and player.name or
			string.match(initiator_name, " vous a$") and string.gsub(initiator_name, " vous a$", "") or
			string.gsub(initiator_name, " a$", "");
		target_name = (target_name == "" and player.name or target_name);

		if (printDebug) then
  		Turbine.Shell.WriteLine("root_broken", line, "ini_name: " .. initiator_name .. " tgt_name: " .. target_name);
		end

		return 16, nil, trim_articles(target_name), nil;
	end
	
	-- 7b) Daze broken
	initiator_name, target_name = string.match(line, "^(.*) délivrée? ?(.*) de l'hébétement\194\160!$");

	if (initiator_name ~= nil) then
		initiator_name =
			string.match(initiator_name, "^Vous avez") and player.name or
			string.match(initiator_name, " vous a$") and string.gsub(initiator_name, " vous a$", "") or
			string.gsub(initiator_name, " a$", "");
		target_name = (target_name == "" and player.name or target_name);

		if (printDebug) then
		  Turbine.Shell.WriteLine("daze_broken", line, "ini_name: " .. initiator_name .. " tgt_name: " .. target_name);
		end

		return 16, nil, target_name, nil;
	end
	
	-- 8) Interrupt line --
	
	local target_name, initiator_name = string.match(line, "^(.*) a été interrompu par (.*)!$");

	if (target_name ~= nil) then
		return 7, trim_articles(initiator_name), trim_articles(target_name);
	end
	
	-- 9) Dispell line (corruption removal) --
	
	local corruption, target_name = string.match(line, "Vous avez dissipé l'effet (.*) affectant (.*)%.$");

	if (corruption ~= nil) then
		initiator_name = player.name;
		-- NB: Currently ignore corruption name
		
		-- Update
		return 8, trim_articles(initiator_name), trim_articles(target_name);
	end
	
	-- 10) Defeat lines ---
	
	-- 10a) Defeat line 1 (mob or played was killed)
	initiator_name = string.match(line, "^.* a vaincu (.*)%.$");

	if (initiator_name ~= nil) then

	-- Update
		return 9, trim_articles(initiator_name);
	end

	-- 10b) Defeat line 2 (mob died)
	initiator_name = string.match(line, "^(.*) meurt%.$");

	if (initiator_name ~= nil) then
		
		-- Update
		return 9, trim_articles(initiator_name);
	end

	-- 10c) Defeat line 3 (a player was killed or died)
	initiator_name = string.match(line, "^(.*) a péri%.$");

	if (initiator_name ~= nil) then
		
		-- Update
		return 9, trim_articles(initiator_name);
	end

	-- 10d) Defeat line 4 (you were killed)
	match = string.match(line, "^.* a réussi à vous mettre hors de combat%.$");

	if (match ~= nil) then
		
		-- Update
		return 9, trim_articles(player.name);
	end

	-- 10e) Defeat line 5 (you died)
	match = string.match(line, "^Un incident vous a réduit à l'impuissance%.$");

	if (match ~= nil) then
		
		-- Update
		return 9, trim_articles(player.name);
	end	
	-- 10f) Defeat line 6 (you killed a mob)
	local initiatorName = string.match(line,"^Votre coup puissant a vaincu (.*)%.$");
	
	if (initiatorName ~= nil) then
		
		-- Update
		return 9,trim_articles(initiatorName);
	end
	
	-- 11) Revive lines --
	
	-- 11a) Revive line 1 (player revived)
	local initiatorName = string.match(line,"^(.*) revient à la vie%.$");
	
	if (initiatorName ~= nil) then
	  
		-- Update
	  return 10,trim_articles(initiatorName);
	end
	
	-- 11b) Revive line 2 (player succumbed)
	local initiatorName = string.match(line,"^(.*) a succombé à ses blessures%.$");
	
	if (initiatorName ~= nil) then
	  
		-- Update
	  return 10,trim_articles(initiatorName);
	end
	
	-- 11c) Revive line 3 (you were revived)
	local match = string.match(line,"^Vous revenez à la vie%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- 11d) Revive line 4 (you succumbed)
	local match = string.match(line,"^You succumb to your wounds%.$");
	
	if (match ~= nil) then
	  initiatorName = player.name;
	  
		-- Update
	  return 10,initiatorName;
	end
	
	-- if we reach here, we were unable to parse the line
	--  (note there is very little that isn't parsed)
end
